var express = require('express');
var router = express.Router();
var user = require("../models/user");
var http = require('http');
var qs = require('querystring');

/**
 * 登录:/user/login.im?user_id=x&token=xx&client_id=xxx&platform=0
 * 参数：
 * user_id：用户ID
 * token：个推的token
 * client_id：个推的clientid
 * platform：平台类型：0为ios，1为android
 */
router.get('/login.im', function (req, res, next) {
    if (req.query.user_id == null
        || req.query.token == null
        || req.query.client_id == null
        || req.query.platform == null) {
        res.send({errno: -1, errmsg: 'parameter error'});
        return;
    }

    user.deleteToken(req.query.token, function (err, result) {
        if (err) {
            res.send({errno: 1, errmsg: 'delete token error'});
            return;
        }

        user.login(req.query.user_id,
            req.query.token,
            req.query.client_id,
            req.query.platform,
            function (err, result) {
                if (err) {
                    res.send({errno: 2, errmsg: 'update users status error'});
                    return;
                }

                res.send({errno: 0, errmsg: 'login successful'});
            });
        });
});

/**
 * 登出:/user/logout.im?user_id=x
 * 参数：
 * user_id：用户ID
 */
router.get('/logout.im', function (req, res, next) {
    if (req.query.user_id == null) {
        res.send({errno: -1, errmsg: 'parameter error'});
        return;
    }

    user.logout(req.query.user_id,
        function (err, result) {
            if (err) {
                res.send({errno: 255, errmsg: 'update users status error'});
                return;
            }

            res.send({errno: 0, errmsg: 'logout successful'});
        });
});

/**
 * 更新app状态:/user/updatestatus.im?user_id=x&status=1
 * 参数：
 * user_id：用户ID
 * status：App状态，0在后台，1在前台
 */
router.get('/updatestatus.im', function (req, res, next) {
    if (req.query.user_id == null || (req.query.status != 0 && req.query.status != 1)) {
        res.send({errno: -1, errmsg: 'parameter error'});
        return;
    }

    user.updateStatus(req.query.user_id, req.query.status,
        function (err, result) {
            if (err) {
                res.send({errno: 255, errmsg: 'update users status error'});
                return;
            }

            res.send({errno: 0, errmsg: 'update status successful'});
        });
});

module.exports = router;
